require(adimpro)
demo(io)
demo(raw)
demo(color)
demo(manipulate)
demo(awsimage)
demo(awspimage)
demo(combine)
demo(segment)